# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import base_module_uninstall
from . import base_partner_merge_automatic_wizard
from . import mail_blacklist_remove
from . import mail_compose_message
from . import mail_activity_schedule
from . import mail_activity_schedule_summary
from . import mail_template_preview
from . import mail_template_reset
from . import mail_followers_edit
